Module: HashRecursiveMerge
- Included in:
- Hash
- Defined in:
- lib/vendor/hash_recursive_merge.rb
Overview
Hash Recursive Merge
Merges a Ruby Hash recursively, Also known as deep merge. Recursive version of Hash#merge and Hash#merge!.
- Category
Ruby
- Package
Hash
- Author
Simone Carletti [email protected]
- Copyright
2007-2008 The Authors
- License
MIT License
- Link
- Source
Instance Method Summary collapse
-
#rmerge(other_hash) ⇒ Object
Recursive version of Hash#merge.
-
#rmerge!(other_hash) ⇒ Object
Recursive version of Hash#merge!.
Instance Method Details
#rmerge(other_hash) ⇒ Object
Recursive version of Hash#merge
Compared with Hash#merge!, this method supports nested hashes.
When both hsh and other_hash contains an entry with the same key,
it merges and returns the values from both arrays.
Compared with Hash#merge, this method provides a different approach
for merging nested hashes.
If the value of a given key is an Hash and both other_hash abd +hsh
includes the same key, the value is merged instead replaced with
other_hash value.
Simply using Hash#merge would return
69 70 71 72 73 74 |
# File 'lib/vendor/hash_recursive_merge.rb', line 69 def rmerge(other_hash) r = {} merge(other_hash) do |key, oldval, newval| r[key] = oldval.class == self.class ? oldval.rmerge(newval) : newval end end |
#rmerge!(other_hash) ⇒ Object
Recursive version of Hash#merge!
Adds the contents of other_hash to hsh,
merging entries in hsh with duplicate keys with those from other_hash.
Compared with Hash#merge!, this method supports nested hashes.
When both hsh and other_hash contains an entry with the same key,
it merges and returns the values from both arrays.
Simply using Hash#merge! would return
38 39 40 41 42 |
# File 'lib/vendor/hash_recursive_merge.rb', line 38 def rmerge!(other_hash) merge!(other_hash) do |_key, oldval, newval| oldval.class == self.class ? oldval.rmerge!(newval) : newval end end |