Method: Kitchen::Configurable::ClassMethods#plugin_version
- Defined in:
- lib/kitchen/configurable.rb
#plugin_version(version) ⇒ Object
Sets the loaded version of this plugin, usually corresponding to the
RubyGems version of the plugin's library. If the plugin does not set
this value, then nil will be used and reported.
369 370 371 |
# File 'lib/kitchen/configurable.rb', line 369 def plugin_version(version) # rubocop:disable Style/TrivialAccessors @plugin_version = version end |