Method: Kitchen::Configurable::ClassMethods#plugin_version

Defined in:
lib/kitchen/configurable.rb

#plugin_version(version) ⇒ Object

Sets the loaded version of this plugin, usually corresponding to the RubyGems version of the plugin’s library. If the plugin does not set this value, then nil will be used and reported.

Examples:

setting a version used by RubyGems


require "kitchen/driver/vagrant_version"

module Kitchen
  module Driver
    class Vagrant < Kitchen::Driver::Base

      plugin_version Kitchen::Driver::VAGRANT_VERSION

    end
  end
end

Parameters:

  • version (String)

    a version string



424
425
426
# File 'lib/kitchen/configurable.rb', line 424

def plugin_version(version) # rubocop:disable Style/TrivialAccessors
  @plugin_version = version
end