Module: Kitchen::Generator
- Defined in:
- lib/kitchen/generator/init.rb
Overview
Namespace for Thor generators that scaffold Test Kitchen configuration into a project.
Defined Under Namespace
Classes: Init
Namespace for Thor generators that scaffold Test Kitchen configuration into a project.
Classes: Init