Class: Kitchen::Instance

Inherits:
Object
  • Object
show all
Includes:
Logging
Defined in:
lib/kitchen/instance.rb

Overview

An instance of a suite running on a platform. A created instance may be a local virtual machine, cloud instance, container, or even a bare metal server, which is determined by the platform's driver.

Author:

Defined Under Namespace

Classes: ActionRunner, FSM

Class Attribute Summary collapse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Logging

#debug, #error, #fatal, #info, #warn

Constructor Details

#initialize(options = {}) ⇒ Instance

Creates a new instance, given a suite and a platform.

Parameters:

  • options (Hash) (defaults to: {})

    configuration for a new suite

Options Hash (options):

  • :suite (Suite)

    the suite (Required)

  • :platform (Platform)

    the platform (Required)

  • :driver (Driver::Base)

    the driver (Required)

  • :provisioner (Provisioner::Base)

    the provisioner (Required)

  • :transport (Transport::Base)

    the transport (Required)

  • :verifier (Verifier)

    the verifier (Required)

  • :logger (Logger)

    the instance logger (default: Kitchen.logger)

  • :state_file (StateFile)

    the state file object to use when tracking instance state (Required)

Raises:

  • (ClientError)

    if one or more required options are omitted



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/kitchen/instance.rb', line 97

def initialize(options = {})
  validate_options(options)

  @suite           = options.fetch(:suite)
  @platform        = options.fetch(:platform)
  @name            = self.class.name_for(@suite, @platform)
  @driver          = options.fetch(:driver)
  @lifecycle_hooks = options.fetch(:lifecycle_hooks)
  @provisioner     = options.fetch(:provisioner)
  @transport       = options.fetch(:transport)
  @verifier        = options.fetch(:verifier)
  @logger          = options.fetch(:logger) { Kitchen.logger }
  @state_file      = options.fetch(:state_file)

  setup_driver
  setup_provisioner
  setup_transport
  setup_verifier
  setup_lifecycle_hooks
end

Class Attribute Details

.mutexesHash

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a hash of mutexes, arranged by Plugin class names.

Returns:

  • (Hash)

    a hash of mutexes, arranged by Plugin class names



37
38
39
# File 'lib/kitchen/instance.rb', line 37

def mutexes
  @mutexes
end

Instance Attribute Details

#driverDriver::Base

Returns driver object which will manage this instance's lifecycle actions.

Returns:

  • (Driver::Base)

    driver object which will manage this instance's lifecycle actions



60
61
62
# File 'lib/kitchen/instance.rb', line 60

def driver
  @driver
end

#lifecycle_hooksLifecycleHooks

Returns lifecycle hooks manager object.

Returns:



63
64
65
# File 'lib/kitchen/instance.rb', line 63

def lifecycle_hooks
  @lifecycle_hooks
end

#loggerLogger (readonly)

Returns the logger for this instance.

Returns:

  • (Logger)

    the logger for this instance



79
80
81
# File 'lib/kitchen/instance.rb', line 79

def logger
  @logger
end

#nameString (readonly)

Returns name of this instance.

Returns:

  • (String)

    name of this instance



56
57
58
# File 'lib/kitchen/instance.rb', line 56

def name
  @name
end

#platformPlatform (readonly)

Returns the target platform configuration.

Returns:

  • (Platform)

    the target platform configuration



53
54
55
# File 'lib/kitchen/instance.rb', line 53

def platform
  @platform
end

#provisionerProvisioner::Base

Returns provisioner object which will provide the setup and invocation instructions for configuration management and other automation tools.

Returns:

  • (Provisioner::Base)

    provisioner object which will provide the setup and invocation instructions for configuration management and other automation tools



68
69
70
# File 'lib/kitchen/instance.rb', line 68

def provisioner
  @provisioner
end

#suiteSuite (readonly)

Returns the test suite configuration.

Returns:

  • (Suite)

    the test suite configuration



50
51
52
# File 'lib/kitchen/instance.rb', line 50

def suite
  @suite
end

#transportTransport::Base

Returns transport object which will communicate with an instance.

Returns:

  • (Transport::Base)

    transport object which will communicate with an instance.



72
73
74
# File 'lib/kitchen/instance.rb', line 72

def transport
  @transport
end

#verifierVerifier

Returns verifier object for instance to manage the verifier installation on this instance.

Returns:

  • (Verifier)

    verifier object for instance to manage the verifier installation on this instance



76
77
78
# File 'lib/kitchen/instance.rb', line 76

def verifier
  @verifier
end

Class Method Details

.name_for(suite, platform) ⇒ String

Generates a name for an instance given a suite and platform.

Parameters:

Returns:

  • (String)

    a normalized, consistent name for an instance



44
45
46
# File 'lib/kitchen/instance.rb', line 44

def name_for(suite, platform)
  "#{suite.name}-#{platform.name}".gsub(%r{[_,/]}, "-").delete(".")
end

Instance Method Details

#cleanup!void

This method returns an undefined value.

Clean up any per-instance resources before exiting.



338
339
340
# File 'lib/kitchen/instance.rb', line 338

def cleanup!
  @transport.cleanup! if @transport
end

#convergeself

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Converges this running instance.

Returns:

  • (self)

    this instance, used to chain actions

See Also:



143
144
145
# File 'lib/kitchen/instance.rb', line 143

def converge
  transition_to(:converge)
end

#createself

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Creates this instance.

Returns:

  • (self)

    this instance, used to chain actions

See Also:



132
133
134
# File 'lib/kitchen/instance.rb', line 132

def create
  transition_to(:create)
end

#current_session_idString?

Returns the current instance session identifier, if one has been established.

Returns:

  • (String, nil)

    the current instance session id



299
300
301
# File 'lib/kitchen/instance.rb', line 299

def current_session_id
  state_file.read[:instance_session_id]
end

#destroyself

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Destroys this instance.

Returns:

  • (self)

    this instance, used to chain actions

See Also:



176
177
178
# File 'lib/kitchen/instance.rb', line 176

def destroy
  transition_to(:destroy)
end

#diagnoseHash

Returns a Hash of configuration and other useful diagnostic information.

Returns:

  • (Hash)

    a diagnostic hash



253
254
255
256
257
258
259
260
261
262
# File 'lib/kitchen/instance.rb', line 253

def diagnose
  result = {}
  %i{
    platform state_file driver provisioner transport verifier lifecycle_hooks
  }.each do |sym|
    obj = send(sym)
    result[sym] = obj.respond_to?(:diagnose) ? obj.diagnose : :unknown
  end
  result
end

#diagnose_pluginsHash

Returns a Hash of configuration and other useful diagnostic information associated with plugins (such as loaded version, class name, etc.).

Returns:

  • (Hash)

    a diagnostic hash



268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/kitchen/instance.rb', line 268

def diagnose_plugins
  result = {}
  %i{driver provisioner verifier transport}.each do |sym|
    obj = send(sym)
    result[sym] = if obj.respond_to?(:diagnose_plugin)
                    obj.diagnose_plugin
                  else
                    :unknown
                  end
  end
  result
end

#doctor_actionObject

Check system and configuration for common errors.



243
244
245
246
247
248
# File 'lib/kitchen/instance.rb', line 243

def doctor_action
  banner "The doctor is in"
  [driver, provisioner, transport, verifier].any? do |obj|
    obj.doctor(state_file.read)
  end
end

#last_actionString

Returns the last successfully completed action state of the instance.

Returns:

  • (String)

    a named action which was last successfully completed



284
285
286
# File 'lib/kitchen/instance.rb', line 284

def last_action
  state_file.read[:last_action]
end

#last_errorString

Returns the error encountered on the last action on the instance

Returns:

  • (String)

    the message of the last error



291
292
293
# File 'lib/kitchen/instance.rb', line 291

def last_error
  state_file.read[:last_error]
end

#log_pathString?

Returns the path to the text log file for this instance.

Returns:

  • (String, nil)

    the instance text log path



306
307
308
# File 'lib/kitchen/instance.rb', line 306

def log_path
  logger.logdev_path
end

#loginObject

Logs in to this instance by invoking a system command, provided by the instance's transport. This could be an SSH command, telnet, or serial console session.

Note This method calls exec and will not return.



212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/kitchen/instance.rb', line 212

def 
  state = state_file.read
  if state[:last_action].nil?
    raise UserError, "Instance #{to_str} has not yet been created"
  end

  lc = transport.connection(state).

  debug(%{Login command: #{lc.command} #{lc.arguments.join(" ")} } \
    "(Options: #{lc.options})")
  Kernel.exec(*lc.exec_args)
end

#package_actionObject

Perform package.



236
237
238
239
# File 'lib/kitchen/instance.rb', line 236

def package_action
  banner "Packaging remote instance"
  driver.package(state_file.read)
end

#remote_exec(command) ⇒ Object

Executes an arbitrary command on this instance.

Parameters:

  • command (String)

    a command string to execute



228
229
230
231
232
# File 'lib/kitchen/instance.rb', line 228

def remote_exec(command)
  transport.connection(state_file.read) do |conn|
    conn.execute(command)
  end
end

#setupself

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Sets up this converged instance for suite tests.

Returns:

  • (self)

    this instance, used to chain actions

See Also:

  • Driver::Base#setup


154
155
156
# File 'lib/kitchen/instance.rb', line 154

def setup
  transition_to(:setup)
end

#state_pathString

Returns the path to the state file for this instance.

Returns:

  • (String)

    the instance state file path



320
321
322
# File 'lib/kitchen/instance.rb', line 320

def state_path
  state_file.path
end

#status(probe: false) ⇒ Hash

Returns normalized liveness status for this instance.

Parameters:

  • probe (Boolean) (defaults to: false)

    whether to probe the transport as well

Returns:

  • (Hash)

    normalized status data



328
329
330
331
332
333
# File 'lib/kitchen/instance.rb', line 328

def status(probe: false)
  state = state_file.read
  result = driver_status(state)
  result[:transport_probe] = transport_probe(state) if probe
  result
end

#structured_log_pathString?

Returns the path to the structured log file for this instance.

Returns:

  • (String, nil)

    the instance structured log path



313
314
315
# File 'lib/kitchen/instance.rb', line 313

def structured_log_path
  logger.structured_logdev_path
end

#test(destroy_mode = :passing) ⇒ self

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Tests this instance by creating, converging and verifying. If this instance is running, it will be pre-emptively destroyed to ensure a clean slate. The instance will be left post-verify in a running state.

Parameters:

  • destroy_mode (Symbol) (defaults to: :passing)

    strategy used to cleanup after instance has finished verifying (default: :passing)

Returns:

  • (self)

    this instance, used to chain actions



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/kitchen/instance.rb', line 190

def test(destroy_mode = :passing)
  elapsed = Benchmark.measure do
    banner "Cleaning up any prior instances of #{to_str}"
    destroy
    banner "Testing #{to_str}"
    verify
    destroy if destroy_mode == :passing
  end
  info "Finished testing #{to_str} #{Util.duration(elapsed.real)}."
  self
ensure
  destroy if destroy_mode == :always
end

#to_strString

Returns a displayable representation of the instance.

Returns:

  • (String)

    an instance display string



121
122
123
# File 'lib/kitchen/instance.rb', line 121

def to_str
  "<#{name}>"
end

#verifyself

TODO:

rescue Driver::ActionFailed and return some kind of null object to gracefully stop action chaining

Verifies this set up instance by executing suite tests.

Returns:

  • (self)

    this instance, used to chain actions

See Also:

  • Driver::Base#verify


165
166
167
# File 'lib/kitchen/instance.rb', line 165

def verify
  transition_to(:verify)
end