Module: Kitchen::Loader
- Defined in:
- lib/kitchen/loader/yaml.rb
Overview
Namespace for configuration loaders, which turn on-disk configuration into the raw data hash Test Kitchen operates on.
Defined Under Namespace
Classes: YAML
Namespace for configuration loaders, which turn on-disk configuration into the raw data hash Test Kitchen operates on.
Classes: YAML