the message to log. In the block form, this is the progname to use in the log message.
Yields:
evaluates to the message to log. This is not evaluated unless the logger’s level is sufficient to log the message. This allows you to create potentially expensive logging messages that are only called when the logger is configured to show them.
Returns:
(nil, true)
—
when the given severity is not high enough (for this particular logger), log no message, and return true
46
# File 'lib/kitchen/logging.rb', line 46logger_method:debug