Module: Kitchen::Which
- Includes:
- ChefUtils::DSL::Which, ChefUtilsWiring
- Defined in:
- lib/kitchen/which.rb
Overview
Mixin providing a which helper for locating executables on the PATH,
wired up to Test Kitchen's chef-utils configuration.
Mixin providing a which helper for locating executables on the PATH,
wired up to Test Kitchen's chef-utils configuration.