Class: Kitchen::Instance::FSM Private

Inherits:
Object
  • Object
show all
Defined in:
lib/kitchen/instance.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

The simplest finite state machine pseudo-implementation needed to manage an Instance.

Author:

Constant Summary collapse

TRANSITIONS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

%i{destroy create converge setup verify}.freeze

Class Method Summary collapse

Class Method Details

.actions(last = nil, desired) ⇒ Array<Symbol>

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns an Array of all transitions to bring an Instance from its last reported transitioned state into the desired transitioned state.

Parameters:

  • last (String, Symbol, nil) (defaults to: nil)

    the last known transitioned state of the Instance, defaulting to nil (for unknown or no history)

  • desired (String, Symbol)

    the desired transitioned state for the Instance

Returns:

  • (Array<Symbol>)

    an Array of transition actions to perform



766
767
768
769
770
771
772
773
774
775
# File 'lib/kitchen/instance.rb', line 766

def self.actions(last = nil, desired)
  last_index = index(last)
  desired_index = index(desired)

  if last_index == desired_index || last_index > desired_index
    Array(TRANSITIONS[desired_index])
  else
    TRANSITIONS.slice(last_index + 1, desired_index - last_index)
  end
end

.index(transition) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Determines the index of a state in the state lifecycle vector. Woah.

Parameters:

  • transition (Symbol, #to_sym)

    a state

  • the (Integer)

    index position



784
785
786
787
788
789
790
# File 'lib/kitchen/instance.rb', line 784

def self.index(transition)
  if transition.nil?
    0
  else
    TRANSITIONS.find_index { |t| t == transition.to_sym }
  end
end